==> crunch_cli-0.6.0b0-py3-none-any.whl: crunch_cli/command/download.py <==
import os
import click
import typing
import requests
import tqdm
import logging

from .. import utils
from .. import constants


def cut_url(url: str):
    try:
        return url[:url.index("?")]
    except ValueError:
        return url


def get_extension(url: str):
    url = cut_url(url)

    if url.endswith(".parquet"):
        return "parquet"

    if url.endswith(".csv"):
        return "csv"

    print(f"unknown file extension: {url}")
    raise click.Abort()


def get_data_urls(
    session: utils.CustomSession,
    data_directory: str
) -> typing.Tuple[typing.Dict[str, str], str, str, str]:
    current_crunch = session.get("/v1/crunches/@current").json()
    urls = session.get(f"/v1/crunches/{current_crunch['number']}/data").json()

    x_train_url = urls["xTrain"]
    x_train_path = os.path.join(
        data_directory,
        f"X_train.{get_extension(x_train_url)}"
    )

    y_train_url = urls["yTrain"]
    y_train_path = os.path.join(
        data_directory,
        f"y_train.{get_extension(y_train_url)}"
    )

    x_test_url = urls["xTest"]
    x_test_path = os.path.join(
        data_directory,
        f"X_test.{get_extension(x_test_url)}"
    )

    data_urls = {
        x_train_path: x_train_url,
        y_train_path: y_train_url,
        x_test_path: x_test_url,
    }

    return data_urls, x_train_path, y_train_path, x_test_path


def _download(url: str, path: str, force: bool):
    logging.info(f"download %s from %s", path, cut_url(url))

    with requests.get(url, stream=True) as response:
        response.raise_for_status()

        file_length = response.headers.get("Content-Length", None)
        file_length = int(file_length) if not None else None

        exists = os.path.exists(path)
        if not force and exists:
            if file_length is None:
                logging.info(f"already exists: skip since unknown size")
                return

            stat = os.stat(path)
            if stat.st_size == file_length:
                logging.info(f"already exists: file length match")
                return

        with open(path, 'wb') as fd, tqdm.tqdm(total=file_length, unit='iB', unit_scale=True, leave=False) as progress:
            for chunk in response.iter_content(chunk_size=8192):
                progress.update(len(chunk))
                fd.write(chunk)


def download(
    session: utils.CustomSession,
    force=False,
):
    os.makedirs(constants.DOT_DATA_DIRECTORY, exist_ok=True)

    data_urls, x_train_path, y_train_path, x_test_path = get_data_urls(
        session, constants.DOT_DATA_DIRECTORY
    )

    for path, url in data_urls.items():
        _download(url, path, force)

    return x_train_path, y_train_path, x_test_path

==> crunch_cli-0.6.2-py3-none-any.whl: crunch_cli/command/download.py <==
import os
import click
import typing
import requests
import tqdm
import logging

from .. import utils
from .. import constants


def cut_url(url: str):
    try:
        return url[:url.index("?")]
    except ValueError:
        return url


def get_extension(url: str):
    url = cut_url(url)

    if url.endswith(".parquet"):
        return "parquet"

    if url.endswith(".csv"):
        return "csv"

    print(f"unknown file extension: {url}")
    raise click.Abort()


def get_data_urls(
    session: utils.CustomSession,
    data_directory: str
) -> typing.Tuple[typing.Dict[str, str], str, str, str]:
    current_crunch = session.get("/v1/crunches/@current").json()
    urls = session.get(f"/v1/crunches/{current_crunch['number']}/data").json()

    x_train_url = urls["xTrain"]
    x_train_path = os.path.join(
        data_directory,
        f"X_train.{get_extension(x_train_url)}"
    )

    y_train_url = urls["yTrain"]
    y_train_path = os.path.join(
        data_directory,
        f"y_train.{get_extension(y_train_url)}"
    )

    x_test_url = urls["xTest"]
    x_test_path = os.path.join(
        data_directory,
        f"X_test.{get_extension(x_test_url)}"
    )

    data_urls = {
        x_train_path: x_train_url,
        y_train_path: y_train_url,
        x_test_path: x_test_url,
    }

    return data_urls, x_train_path, y_train_path, x_test_path


def _download(url: str, path: str, force: bool):
    print(f"download {path} from {cut_url(url)}")

    with requests.get(url, stream=True) as response:
        response.raise_for_status()

        file_length = response.headers.get("Content-Length", None)
        file_length = int(file_length) if not None else None

        exists = os.path.exists(path)
        if not force and exists:
            if file_length is None:
                print(f"already exists: skip since unknown size")
                return

            stat = os.stat(path)
            if stat.st_size == file_length:
                print(f"already exists: file length match")
                return

        with open(path, 'wb') as fd, tqdm.tqdm(total=file_length, unit='iB', unit_scale=True, leave=False) as progress:
            for chunk in response.iter_content(chunk_size=8192):
                progress.update(len(chunk))
                fd.write(chunk)


def download(
    session: utils.CustomSession,
    force=False,
):
    os.makedirs(constants.DOT_DATA_DIRECTORY, exist_ok=True)

    data_urls, x_train_path, y_train_path, x_test_path = get_data_urls(
        session, constants.DOT_DATA_DIRECTORY
    )

    for path, url in data_urls.items():
        _download(url, path, force)

    return x_train_path, y_train_path, x_test_path
